#
# spec file for package rshim
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019 Mellanox Technologies. All Rights Reserved.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rshim
Version:        2.0.29.1
Release:        bp156.1.1
Summary:        User-space driver for Mellanox BlueField SoC
License:        GPL-2.0 or BSD-3-Clause
Group:          System/Management
URL:            https://github.com/mellanox/rshim-user-space
Source0:        %{name}-%{version}.tar
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse-devel
BuildRequires:  pciutils-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)

%description
This is the user-space driver to access the BlueField SoC via the rshim
interface. It provides ways to push boot stream, debug the target or login
via the virtual console or network interface.

%prep
%setup -q

%build
./bootstrap.sh
%configure
%make_build

%install
%make_install -C src INSTALL_DIR="%{buildroot}%{_sbindir}"
install -d %{buildroot}%{_unitdir}
install -m 0644 rshim.service %{buildroot}%{_unitdir}
install -d %{buildroot}%{_mandir}/man8
install -m 0644 man/rshim.8 %{buildroot}%{_mandir}/man8

%files
%license LICENSE
%doc README.md
%{_unitdir}/rshim.service
%{_sbindir}/rshim
%{_mandir}/man8/rshim.8%{?ext_man}

%changelog
* Fri May 10 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.29.1 (jsc#PED-6843 jsc#PED-6979)
  * Output SECURE_NIC_MODE in /dev/rshim<N>/misc
  * Allow remote installation via bfb-install
  * Make DROP_MODE more robust
  * Avoid race in bfb push when accessing from BMC and rshim tool in parallel
  * Fix handshake between NIC F and rshim over PCIe
* Thu Mar  7 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.20.0 (jsc#PED-6843 jsc#PED-6979)
  * Adjust delay time for nic_fw reset
  * Add BFB completion condition for enhanced NIC mode
  * Fixes for potential high CPU utilization
* Thu Nov  2 2023 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.12.1
  * Display uptime in seconds for BF3
  * Add fuse3 support
* Wed Aug 30 2023 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.9
  * Fix fallback logic of direct mapping
  * Make timeout configurable through /dev/rshimX/misc
* Fri Apr 21 2023 Matthias Brugger <mbrugger@suse.com>
- Update service to new tag format
- update to 2.0.7
  * adjust reset delay
  * avoid leak the file descriptor for /dev/uio
* Thu Mar 16 2023 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.19.2
  * fix potential NULL pointer access during USB disconnection
  * fix vfio and direct mapping mode with several devices
  * avoid use of stale cached pci_dev pointer after device reset
  * adjust reset delay
  * update to dual-licensese GPL-2.0/BSD-3-Clause
* Thu Sep 15 2022 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.13.7
  * make use of rshim with several devices more efficient
  * support 32 bit CR space possible on BF3 USB access
  * support more transfer sizes
  * add new device ID for BF3
  * allow to en/disable VFIO/UIO support via rshim.conf
  * make restart of rshim process more robust fixing potential race
  * set default boot timeout to 150 seconds
* Thu Jul 14 2022 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.11.5
  * Fix a possible crash on PCIe for BF1/2
  * Fix possible race condition when several rshim devices are present
  * Fix a kernel crash when undbinding from uio
  * Detect new USB/rshim hot plug
* Fri Nov 19 2021 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.2.2
  * bfb-install: Handle new indications for installation completion
  * Make USB reset configurable and set to 3 seconds
  * Move USB reset to USB up event
* Wed Sep 29 2021 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.1.5
  * Disable the background timer if no rshim devices
  * Setting default path for rshim config file
  * Refine when some workarounds should be applied
  * Fix hypervisor crash when several cards boot or push streams
  * Set MTU to standard max size
* Thu Mar 11 2021 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.5.10
  * fix possible tmfifo data loss in PCIe interface
  * fix USB deadlock
  * reduce CPU load when no rshim device present
  * add PCIe hotplug support
* Mon Jan 25 2021 Matthias Brugger <mbrugger@suse.com>
- fix _service file
- update to 2.0.5.8.3
  * fix various issues
  * add workaround for Bluefield-2 REV-0
* Thu Nov 19 2020 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.55.1
  * add bfb-install script
- fix version number naming
- add versioning to _service file
* Wed Nov 11 2020 Matthias Brugger <mbrugger@suse.com>
- update to latest version (jsc#SLE-16098 jsc#SLE-13565 jsc#SLE-16108 jsc#SLE-15271)
  * Some robust fixes for USB rshim
  * Fix a typo in pcie mmap
  * Check rshim accessibility when re-enabling it
  * Enable console output during boot stream pushing
  * Add some delay for the pcie_lf probe
  * Auto-start rshim service after installation
* Thu Oct  1 2020 Matthias Brugger <mbrugger@suse.com>
- update to latest version
  * enable BlueField-2 support
  * Add configuration file support
* Wed Jun 10 2020 Matthias Brugger <mbrugger@suse.com>
- add _service file
- update to latest version
* Mon Apr 27 2020 Matthias Brugger <mbrugger@suse.com>
- add version 2.0.4
